@@ -1,6 +1,8 @@
 ################################################################################
 ################################################################################
-
+##
+##
+#'@noRd
 NumFail<- function(StaPar,Yt,Event,Break,Xt){
     if (is.null(Event))stop("Bad input Event")
     if (is.null(Break))stop("Bad input Break")
@@ -19,6 +21,5 @@ NumFail<- function(StaPar,Yt,Event,Break,Xt){
   nf=ni
   return(nf)
 }
-NumFail <- cmpfun(NumFail)
 ################################################################################
 ################################################################################
